@@ -1601,3 +1601,131 @@ def test_client_query_error(server, mocker):
     # Test
     with pytest.raises(HTTPError):
         client.query(query.SECTORS)
+
+
+def test_client_get_status(server):
+    """Should raise HTTPError if there is a client error."""
+    html = """
+        {
+            "StatusUid": 1,
+            "PanelLeds": {
+                "InputsLed": 2,
+                "AnomaliesLed": 1,
+                "AlarmLed": 0,
+                "TamperLed": 0
+            },
+            "PanelAnomalies": {
+                "HasAnomaly": false,
+                "PanelTamper": 0,
+                "PanelNoPower": 0,
+                "PanelLowBattery": 0,
+                "GsmAnomaly": 0,
+                "GsmLowBalance": 0,
+                "PstnAnomaly": 0,
+                "SystemTest": 0,
+                "ModuleRegistration": 0,
+                "RfInterference": 0,
+                "InputFailure": 0,
+                "InputAlarm": 0,
+                "InputBypass": 0,
+                "InputLowBattery": 0,
+                "InputNoSupervision": 0,
+                "DeviceTamper": 0,
+                "DeviceFailure": 0,
+                "DeviceNoPower": 0,
+                "DeviceLowBattery": 0,
+                "DeviceNoSupervision": 0,
+                "DeviceSystemBlock": 0
+            },
+            "PanelAlignmentAdv": {
+                "ManualFwUpAvailable": false,
+                "Id": 1,
+                "Index": -1,
+                "Element": 0
+            }
+        }
+    """
+    server.add(responses.POST, "https://example.com/api/statusadv", body=html, status=200)
+    client = ElmoClient(base_url="https://example.com", domain="domain")
+    client._session_id = "test"
+    # Test
+    result = client.get_status()
+    body = server.calls[0].request.body
+    assert body == "sessionId=test"
+    assert result == {
+        "inputs_led": 2,
+        "anomalies_led": 1,
+        "alarm_led": 0,
+        "tamper_led": 0,
+        "has_anomaly": False,
+        "panel_tamper": 0,
+        "panel_no_power": 0,
+        "panel_low_battery": 0,
+        "gsm_anomaly": 0,
+        "gsm_low_balance": 0,
+        "pstn_anomaly": 0,
+        "system_test": 0,
+        "module_registration": 0,
+        "rf_interference": 0,
+        "input_failure": 0,
+        "input_alarm": 0,
+        "input_bypass": 0,
+        "input_low_battery": 0,
+        "input_no_supervision": 0,
+        "device_tamper": 0,
+        "device_failure": 0,
+        "device_no_power": 0,
+        "device_low_battery": 0,
+        "device_no_supervision": 0,
+        "device_system_block": 0,
+    }
+
+
+def test_client_get_status_http_error(server):
+    """Should raise HTTPError if there is a client error."""
+    server.add(responses.POST, "https://example.com/api/statusadv", body="500 Error", status=500)
+    client = ElmoClient(base_url="https://example.com", domain="domain")
+    client._session_id = "test"
+    # Test
+    with pytest.raises(HTTPError):
+        client.get_status()
+    assert len(server.calls) == 1
+
+
+def test_client_get_status_invalid_json(server):
+    """Should raise ParseError if the response is unexpected."""
+    server.add(responses.POST, "https://example.com/api/statusadv", body="Invalid JSON", status=200)
+    client = ElmoClient(base_url="https://example.com", domain="domain")
+    client._session_id = "test"
+    # Test
+    with pytest.raises(ParseError):
+        client.get_status()
+    assert len(server.calls) == 1
+
+
+def test_client_get_status_missing_data(server):
+    """Should raise ParseError if some response data is missing."""
+    html = """
+        {
+            "StatusUid": 1,
+            "PanelLeds": {
+                "InputsLed": 2,
+                "AnomaliesLed": 1,
+                "AlarmLed": 0,
+                "TamperLed": 0
+            },
+            "PanelAlignmentAdv": {
+                "ManualFwUpAvailable": false,
+                "Id": 1,
+                "Index": -1,
+                "Element": 0
+            }
+        }
+    """
+    server.add(responses.POST, "https://example.com/api/statusadv", body=html, status=200)
+    client = ElmoClient(base_url="https://example.com", domain="domain")
+    client._session_id = "test"
+    # Test
+    with pytest.raises(ParseError):
+        client.get_status()
+    assert len(server.calls) == 1
